@@ -24,7 +24,14 @@
 
 NMapplyFilters <- function(data,file,text,lines,invert=FALSE,as.fun,quiet) {
 
+#### Section start: Dummy variables, only not to get NOTE's in pacakge checks ####
+
+    . <- NULL
+    variable <- NULL
+    value <- NULL
     
+### Section end: Dummy variables, only not to get NOTE's in pacakge checks
+
     
     if(missing(quiet)) quiet <- NULL
     quiet <- NMdataDecideOption("quiet",quiet)
@@ -50,16 +57,7 @@ NMapplyFilters <- function(data,file,text,lines,invert=FALSE,as.fun,quiet) {
     file <- NULL
     text <- NULL
 
-### if data is a list of data and meta, we need to split it out and
-### remember to update meta. This is needed for NMscanData, not
-### NMscanInput. We leave meta data untouched. This part is due to a previous design of NMscanInput. 
-    ## details <- FALSE
-    ## data.meta <- list()
-    ## if(is.list(data) && !is.data.frame(data)){
-    ##     data.meta <- data$meta
-    ##     data <- data$data
-    ##     details <- TRUE
-    ## }
+### We leave meta data untouched. This part is due to a previous design of NMscanInput. 
     
     data.meta <- NMinfoDT(data)
 
@@ -121,7 +119,7 @@ NMapplyFilters <- function(data,file,text,lines,invert=FALSE,as.fun,quiet) {
         scs2 <- regmatches(scs,regexpr(regstring,scs))
         ## expressions.sc <- c(expressions.sc,paste0("!grepl('^",scs2,"\",",name.c1,")"))
         ## expressions.sc <- c(expressions.sc,paste0("!grepl('^",scs2,"','",name.c1,"')"))
-        expressions.sc <- c(expressions.sc,paste0("!grepl('[",scs2,"]',`",name.c1,"`)"))
+        expressions.sc <- c(expressions.sc,paste0("!grepl('^[",scs2,"]',`",name.c1,"`)"))
         scs <- scs[!grepl(regstring,scs)]
     }
 
@@ -145,6 +143,15 @@ NMapplyFilters <- function(data,file,text,lines,invert=FALSE,as.fun,quiet) {
     ## (DOSE 10) means (DOSE==10) in NMTRAN. 
     expressions.list <- sub("([[:alpha:]]+) +([[:alnum:]]+)","\\1==\\2",expressions.list)
 
+    vars.cond <- sub("([[:alnum:]])[^[:alnum:]]+.*","\\1",expressions.list)
+
+    if(length(vars.cond)){
+        missings <- listMissings(data,cols=vars.cond)
+        if(!is.null(missings)&&nrow(missings)>0){
+            warning(paste("Missing values found in columns used for ACCEPT/IGNORE statements. This is not supported. If at all possible, please use a unique row identifier to merge by and/or make sure values are not missing in these colums.\n",paste(capture.output(print(missings[,.N,by=.(variable,value)])),collapse="\n")))
+            
+        }
+    }
     
     cond.combine <- "|"
     ## remember to negate everything if the type is ignore
@@ -198,5 +205,5 @@ NMapplyFilters <- function(data,file,text,lines,invert=FALSE,as.fun,quiet) {
     
     writeNMinfo(data,meta=data.meta,append=TRUE)
     data
- 
+    
 }
