@@ -14,6 +14,8 @@ fix.time <- function(x){
     meta.x$details$mtime.input <- NULL
     meta.x$details$mtime.lst <- NULL
     meta.x$details$mtime.mod <- NULL
+    meta.x$datafile$path <- NULL
+    meta.x$datafile$path.rds <- NULL
     meta.x$tables$file <- NULL
     meta.x$tables$file.mtime <- NULL
     setattr(x,"NMdata",meta.x)
@@ -26,14 +28,14 @@ NMdataConf(reset=TRUE)
 test_that("basic",{
 
     fileRef <- "testReference/NMscanInput_1.rds"
-    file.lst <- system.file("examples/nonmem/xgxr004.lst",package="NMdata")
+    file.lst <- "testData/nonmem/xgxr004.lst"
 
     ## res1 <- NMscanInput(file=file.lst,applyFilters = T,as.fun="none")
 ### using as.data.table for as.fun is not recommended but still allowed
-    res1 <-
+    res <-
         NMscanInput(file=file.lst,applyFilters = T,as.fun="data.table")
-fix.time(res1)
-    expect_equal_to_reference(res1,fileRef,version=2)
+    fix.time(res)
+    expect_equal_to_reference(res,fileRef,version=2)
 })
 
 
@@ -42,16 +44,16 @@ test_that("input has NMdata meta data",{
     fileRef <- "testReference/NMscanInput_2.rds"
     ## load_all("c:/Users/delff/working_copies/NMdata")
 
-    file.lst <- system.file("examples/nonmem/xgxr011.lst", package="NMdata")
+    file.lst <- "testData/nonmem/xgxr011.lst"
     ## NMgetSection(file.lst,section="PROBLEM")
     ## NMgetSection(file.lst,section="DATA")
     
 
-    res1 <- NMscanInput(file=file.lst,applyFilters = T,as.fun="data.table")
-fix.time(res1)
-    nm1 <- NMinfo(res1)
+    res <- NMscanInput(file=file.lst,applyFilters = T,as.fun="data.table")
+    fix.time(res)
+    nm1 <- NMinfo(res)
     expect_equal_to_reference(nm1,fileRef,version=2)
-    
+## readRDS(fileRef)$tables; nm1$tables    
     
 })
 
@@ -60,18 +62,19 @@ test_that("single = filter",{
     ## load_all("c:/Users/delff/working_copies/NMdata")
 
 
-    file.lst <- system.file("examples/nonmem/xgxr009.lst", package="NMdata")
+    file.lst <- "testData/nonmem/xgxr009.lst"
     ## NMgetSection(file.lst,section="PROBLEM")
     ## NMgetSection(file.lst,section="DATA")
-    res1 <- NMscanInput(file=file.lst,applyFilters = T,as.fun="data.table")
-    expect_equal(res1[,unique(DOSE)],10)
+    res <- NMscanInput(file=file.lst,applyFilters = T,as.fun="data.table")
+    expect_equal(res[,unique(DOSE)],10)
     
 })
 
 
 test_that("Duplicate columns in input data",{
     fileRef <- "testReference/NMscanInput3.rds"
-    file.lst <- system.file("examples/nonmem/xgxr015.lst", package="NMdata")
+    ## file.lst <- system.file("examples/nonmem/xgxr015.lst", package="NMdata")
+    file.lst <- "testData/nonmem/xgxr015.lst"
 
     ## res <- NMscanData(file=file.lst)
     ## res <- NMscanData(file=file.lst)
@@ -87,11 +90,12 @@ test_that("single-char ignore",{
     fileRef <- "testReference/NMscanInput4.rds"
     file.lst <- "testData/nonmem/estim_debug.lst"
 
-    inpdat <- NMscanInput(file=file.lst,applyFilters=T,file.mod=function(x)sub("\\.lst$",".ctl",x))
-    expect_equal(nrow(inpdat),98)
+    ## inpdat <- NMscanInput(file=file.lst,applyFilters=T,file.mod=function(x)sub("\\.lst$",".ctl",x))
+    res <- NMscanInput(file=file.lst,applyFilters=T,file.mod=function(x)fnExtension(x,".ctl"))
+    expect_equal(nrow(res),98)
     
-    fix.time(inpdat)
-    expect_equal_to_reference(inpdat,fileRef,version=2)
+    fix.time(res)
+    expect_equal_to_reference(res,fileRef,version=2)
 
 })
 
@@ -113,21 +117,21 @@ test_that("Erroneously basing a filter on translated column names",{
     expect_error(
         NMscanInput("testData/nonmem/min036mod.mod",applyFilters=TRUE)
     )
-    })
+})
 
 test_that("Including meta data",{
     NMdataConf(reset=T)
     fileRef <- "testReference/NMscanInput6.rds"
-    file.lst <- system.file("examples/nonmem/xgxr004.lst",package="NMdata")
+    file.lst <- "testData/nonmem/xgxr004.lst"
 
-    res1 <-
+    res <-
         NMscanInput(file=file.lst,applyFilters = T,details=T, as.fun="data.table")
 
-    ## res1$meta$details$file <- "file"
-    ## res1$meta$details$file.mtime <- NULL
-    fix.time(res1)    
+    ## res$meta$details$file <- "file"
+    ## res$meta$details$file.mtime <- NULL
+    fix.time(res)    
     
-    expect_equal_to_reference(res1,fileRef,version=2)
+    expect_equal_to_reference(res,fileRef,version=2)
     
     
 })
@@ -138,12 +142,12 @@ test_that("CYCLE=DROP",{
     fileRef <- "testReference/NMscanInput_7.rds"
     file.lst <- system.file("examples/nonmem/xgxr002.lst",package="NMdata")
 
-    ## res1 <- NMscanInput(file=file.lst,applyFilters = T,as.fun="none")
+    ## res <- NMscanInput(file=file.lst,applyFilters = T,as.fun="none")
 ### using as.data.table for as.fun is not recommended but still allowed
-    res1 <-
+    res <-
         NMscanInput(file=file.lst,applyFilters = T,as.fun="data.table")
 
-    fix.time(res1)
-    nm1 <- NMinfo(res1)
+    fix.time(res)
+    nm1 <- NMinfo(res)
     expect_equal_to_reference(nm1,fileRef,version=2)
 })
